#!/usr/bin/env bash

# Check if we have exactly 3 arguments
# 1: PORT (e.g. 8081)
# 2: VIDEO_PATH (e.g. /Users/okji/Desktop/my_plex)
# 3: VIDEO_LOCATION (e.g. /myplex/video/)
if [ $# -ne 3 ]; then
  echo "Usage: $0 <PORT> <VIDEO_PATH> <VIDEO_LOCATION>"
  exit 1
fi

VIDEO_HOSTING_PORT=$1
VIDEO_HOSTING_PATH=$2
VIDEO_LOCATION=$3

# Ensure Homebrew is installed
if ! command -v brew &> /dev/null; then
    echo "Homebrew not found. Please install Homebrew first: https://brew.sh/"
    exit 1
fi

# Install Apache (httpd) if not installed
if ! brew list httpd &>/dev/null; then
    echo "Installing Apache (httpd) via Homebrew..."
    brew install httpd
fi

HTTPD_CONF_DIR="/opt/homebrew/etc/httpd"
VHOSTS_DIR="${HTTPD_CONF_DIR}/vhosts"

# Ensure the vhosts directory exists
if [ ! -d "$VHOSTS_DIR" ]; then
    mkdir -p "$VHOSTS_DIR"
fi

# Make sure the video directory is accessible
chmod -R 755 "${VIDEO_HOSTING_PATH}"

# Create a VirtualHost config file
# This will:
# - Listen on VIDEO_HOSTING_PORT
# - Set DocumentRoot to VIDEO_HOSTING_PATH
# - Allow directory browsing (Indexes)
# - By default, Apache supports Range requests for static files
VHOST_CONF_FILE="${VHOSTS_DIR}/video_hosting.conf"

cat <<EOF > "${VHOST_CONF_FILE}"
Listen ${VIDEO_HOSTING_PORT}

<VirtualHost *:${VIDEO_HOSTING_PORT}>
    ServerName localhost
    DocumentRoot "${VIDEO_HOSTING_PATH}"

    # Enable directory browsing
    <Directory "${VIDEO_HOSTING_PATH}">
        Options +Indexes +FollowSymLinks
        AllowOverride None
        Require all granted
    </Directory>

    # If you want a specific location (e.g. /myplex/video/),
    # you can use Alias:
    Alias ${VIDEO_LOCATION} "${VIDEO_HOSTING_PATH}"

    <Directory "${VIDEO_HOSTING_PATH}">
        Options +Indexes +FollowSymLinks
        Require all granted
    </Directory>
</VirtualHost>
EOF

# Ensure that the main httpd.conf includes the vhosts directory
if ! grep -q "Include ${VHOSTS_DIR}/*.conf" "${HTTPD_CONF_DIR}/httpd.conf"; then
    echo "Include ${VHOSTS_DIR}/*.conf" >> "${HTTPD_CONF_DIR}/httpd.conf"
fi

# Restart Apache using brew services
brew services restart httpd

echo "Apache reloaded with new video hosting config."
echo "Try accessing: http://localhost:${VIDEO_HOSTING_PORT}${VIDEO_LOCATION}"
